==> apache-camel-3.22.4-src.zip: apache-camel-3.22.4/core/camel-core-model/src/main/java/org/apache/camel/model/language/MvelExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.apache.camel.spi.Metadata;

/**
 * Evaluates a MVEL template.
 */
@Metadata(firstVersion = "2.0.0", label = "language,java", title = "MVEL")
@XmlRootElement(name = "mvel")
@XmlAccessorType(XmlAccessType.FIELD)
public class MvelExpression extends TypedExpressionDefinition {

    public MvelExpression() {
    }

    public MvelExpression(String expression) {
        super(expression);
    }

    private MvelExpression(Builder builder) {
        super(builder);
    }

    @Override
    public String getLanguage() {
        return "mvel";
    }

    /**
     * {@code Builder} is a specific builder for {@link MvelExpression}.
     */
    @XmlTransient
    public static class Builder extends AbstractBuilder<Builder, MvelExpression> {

        @Override
        public MvelExpression end() {
            return new MvelExpression(this);
        }
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/core/camel-core-model/src/main/java/org/apache/camel/model/language/MvelExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlTransient;

import org.apache.camel.spi.Metadata;

/**
 * Evaluates a MVEL template.
 */
@Metadata(firstVersion = "2.0.0", label = "language,java", title = "MVEL")
@XmlRootElement(name = "mvel")
@XmlAccessorType(XmlAccessType.FIELD)
public class MvelExpression extends TypedExpressionDefinition {

    public MvelExpression() {
    }

    protected MvelExpression(MvelExpression source) {
        super(source);
    }

    public MvelExpression(String expression) {
        super(expression);
    }

    private MvelExpression(Builder builder) {
        super(builder);
    }

    @Override
    public MvelExpression copyDefinition() {
        return new MvelExpression(this);
    }

    @Override
    public String getLanguage() {
        return "mvel";
    }

    /**
     * {@code Builder} is a specific builder for {@link MvelExpression}.
     */
    @XmlTransient
    public static class Builder extends AbstractBuilder<Builder, MvelExpression> {

        @Override
        public MvelExpression end() {
            return new MvelExpression(this);
        }
    }
}
